@@ -1824,9 +1824,9 @@ yyreduce:
 #line 338 "rc-gram.y" /* yacc.c:1646  */
     {
 	     (yyval.node) = rc_node_create (rc_node_bool, &(yylsp[-1]).beg);
-	     (yyval.node)->v.bool.op = bool_and;
-	     (yyval.node)->v.bool.left = (yyvsp[-2].node);
-	     (yyval.node)->v.bool.right = (yyvsp[0].node);
+	     (yyval.node)->v.vbool.op = bool_and;
+	     (yyval.node)->v.vbool.left = (yyvsp[-2].node);
+	     (yyval.node)->v.vbool.right = (yyvsp[0].node);
 	   }
 #line 1832 "rc-gram.c" /* yacc.c:1646  */
     break;
@@ -1835,9 +1835,9 @@ yyreduce:
 #line 345 "rc-gram.y" /* yacc.c:1646  */
     {
 	     (yyval.node) = rc_node_create (rc_node_bool, &(yylsp[-1]).beg);
-	     (yyval.node)->v.bool.op = bool_or;
-	     (yyval.node)->v.bool.left = (yyvsp[-2].node);
-	     (yyval.node)->v.bool.right = (yyvsp[0].node);
+	     (yyval.node)->v.vbool.op = bool_or;
+	     (yyval.node)->v.vbool.left = (yyvsp[-2].node);
+	     (yyval.node)->v.vbool.right = (yyvsp[0].node);
 	   }
 #line 1843 "rc-gram.c" /* yacc.c:1646  */
     break;
@@ -1846,9 +1846,9 @@ yyreduce:
 #line 352 "rc-gram.y" /* yacc.c:1646  */
     {
 	     (yyval.node) = rc_node_create (rc_node_bool, &(yylsp[-1]).beg);
-	     (yyval.node)->v.bool.op = bool_not;
-	     (yyval.node)->v.bool.left = (yyvsp[0].node);
-	     (yyval.node)->v.bool.right = NULL;
+	     (yyval.node)->v.vbool.op = bool_not;
+	     (yyval.node)->v.vbool.left = (yyvsp[0].node);
+	     (yyval.node)->v.vbool.right = NULL;
 	   }
 #line 1854 "rc-gram.c" /* yacc.c:1646  */
     break;
@@ -1991,19 +1991,19 @@ yyreduce:
 #line 459 "rc-gram.y" /* yacc.c:1646  */
     {
 	     RC_NODE *node = rc_node_create (rc_node_expr, &(yylsp[-4]).beg);
-	     node->v.expr.part = (yyvsp[-4].msgpart).part;
-	     node->v.expr.key = (yyvsp[-4].msgpart).string;
-	     node->v.expr.sep = (yyvsp[-3].string);
-	     node->v.expr.re = anubis_regex_compile ((yyvsp[0].string), (yyvsp[-1].num));
+	     node->v.vexpr.part = (yyvsp[-4].msgpart).part;
+	     node->v.vexpr.key = (yyvsp[-4].msgpart).string;
+	     node->v.vexpr.sep = (yyvsp[-3].string);
+	     node->v.vexpr.re = anubis_regex_compile ((yyvsp[0].string), (yyvsp[-1].num));
 	     free ((yyvsp[0].string));
 	     if ((yyvsp[-2].eq))
 	       (yyval.node) = node;
 	     else
 	       {
 		 (yyval.node) = rc_node_create (rc_node_bool, &(yylsp[-4]).beg);
-		 (yyval.node)->v.bool.op = bool_not;
-		 (yyval.node)->v.bool.left = node;
-		 (yyval.node)->v.bool.right = NULL;
+		 (yyval.node)->v.vbool.op = bool_not;
+		 (yyval.node)->v.vbool.left = node;
+		 (yyval.node)->v.vbool.right = NULL;
 	       }
 	   }
 #line 2010 "rc-gram.c" /* yacc.c:1646  */
@@ -2068,9 +2068,9 @@ yyreduce:
 #line 521 "rc-gram.y" /* yacc.c:1646  */
     {
 	     (yyval.node) = rc_node_create (rc_node_expr, &(yylsp[-2]).beg);
-	     (yyval.node)->v.expr.part = HEADER;
-	     (yyval.node)->v.expr.key = strdup (X_ANUBIS_RULE_HEADER);
-	     (yyval.node)->v.expr.re = anubis_regex_compile ((yyvsp[0].string), (yyvsp[-1].num));
+	     (yyval.node)->v.vexpr.part = HEADER;
+	     (yyval.node)->v.vexpr.key = strdup (X_ANUBIS_RULE_HEADER);
+	     (yyval.node)->v.vexpr.re = anubis_regex_compile ((yyvsp[0].string), (yyvsp[-1].num));
 	     free ((yyvsp[0].string));
 	   }
 #line 2077 "rc-gram.c" /* yacc.c:1646  */
@@ -2764,10 +2764,10 @@ rc_asgn_destroy (RC_ASGN *asgn)
 /* Bools */
 
 void
-rc_bool_destroy (RC_BOOL *bool)
+rc_bool_destroy (RC_BOOL *b)
 {
-  rc_node_destroy (bool->left);
-  rc_node_destroy (bool->right);
+  rc_node_destroy (b->left);
+  rc_node_destroy (b->right);
 }
 
 /* Nodes */
@@ -2791,12 +2791,12 @@ rc_node_destroy (RC_NODE *node)
   switch (node->type)
     {
     case rc_node_bool:
-      rc_bool_destroy (&node->v.bool);
+      rc_bool_destroy (&node->v.vbool);
       break;
     
     case rc_node_expr:
-      free (node->v.expr.key);
-      anubis_regex_free (&node->v.expr.re);
+      free (node->v.vexpr.key);
+      anubis_regex_free (&node->v.vexpr.re);
     }
   rc_destroy_loc (&node->loc);
   xfree (node);
@@ -2826,37 +2826,37 @@ rc_node_print (RC_NODE *node)
   switch (node->type)
     {
     case rc_node_expr:
-      printf ("%s", part_string (node->v.expr.part));
-      if (node->v.expr.key && node->v.expr.key[0] != '\n')
-	printf ("[%s]",node->v.expr.key);
-      if (node->v.expr.sep)
-	printf ("(%s)", node->v.expr.sep);
+      printf ("%s", part_string (node->v.vexpr.part));
+      if (node->v.vexpr.key && node->v.vexpr.key[0] != '\n')
+	printf ("[%s]",node->v.vexpr.key);
+      if (node->v.vexpr.sep)
+	printf ("(%s)", node->v.vexpr.sep);
       printf (" ");
-      anubis_regex_print (node->v.expr.re);
+      anubis_regex_print (node->v.vexpr.re);
       break;
 		
     case rc_node_bool:
-      switch (node->v.bool.op)
+      switch (node->v.vbool.op)
 	{
 	case bool_not:
 	  printf ("NOT (");
-	  rc_node_print (node->v.bool.left);
+	  rc_node_print (node->v.vbool.left);
 	  printf (")");
 	  break;
       
 	case bool_and:
 	  printf ("AND (");
-	  rc_node_print (node->v.bool.left);
+	  rc_node_print (node->v.vbool.left);
 	  printf (",");
-	  rc_node_print (node->v.bool.right);
+	  rc_node_print (node->v.vbool.right);
 	  printf (")");
 	  break;
       
 	case bool_or:
 	  printf ("OR (");
-	  rc_node_print (node->v.bool.left);
+	  rc_node_print (node->v.vbool.left);
 	  printf (",");
-	  rc_node_print (node->v.bool.right);
+	  rc_node_print (node->v.vbool.right);
 	  printf (")");
 	  break;
 	}
@@ -3279,7 +3279,7 @@ eval_warning (struct eval_env *env, const char *fmt, ...)
 
 static void asgn_eval (struct eval_env *env, RC_ASGN *asgn);
 static int node_eval (struct eval_env *env, RC_NODE *node);
-static int bool_eval (struct eval_env *env, RC_BOOL *bool);
+static int bool_eval (struct eval_env *env, RC_BOOL *b);
 static void cond_eval (struct eval_env *env, RC_COND *cond);
 static void rule_eval (struct eval_env *env, RC_RULE *rule);
 static void stmt_list_eval (struct eval_env *env, RC_STMT *stmt);
@@ -3471,7 +3471,7 @@ expr_eval (struct eval_env *env, RC_EXPR *expr)
 
   if (env->refstr && anubis_regex_refcnt (expr->re))
     {
-      argcv_free (-1, env->refstr);
+      argv_free (env->refstr);
       env->refcnt = 0;
       env->refstr = NULL;
     }
@@ -3521,11 +3521,11 @@ node_eval (struct eval_env *env, RC_NODE *node)
   switch (node->type)
     {
     case rc_node_bool:
-      rc = bool_eval (env, &node->v.bool);
+      rc = bool_eval (env, &node->v.vbool);
       break;
     
     case rc_node_expr:
-      rc = expr_eval (env, &node->v.expr);
+      rc = expr_eval (env, &node->v.vexpr);
       break;
     
     default:
@@ -3536,11 +3536,11 @@ node_eval (struct eval_env *env, RC_NODE *node)
 }
 
 int
-bool_eval (struct eval_env *env, RC_BOOL *bool)
+bool_eval (struct eval_env *env, RC_BOOL *bv)
 {
-  int rc = node_eval (env, bool->left);
+  int rc = node_eval (env, bv->left);
 
-  switch (bool->op)
+  switch (bv->op)
     {
     case bool_not:
       return !rc;
@@ -3555,7 +3555,7 @@ bool_eval (struct eval_env *env, RC_BOOL *bool)
 	return 1;
       break;
     }
-  return node_eval (env, bool->right);
+  return node_eval (env, bv->right);
 }
 
 void
@@ -3622,7 +3622,7 @@ eval_section (int method, RC_SECTION *sec, struct rc_secdef *secdef,
     stmt_list_eval (&env, sec->stmt);
   
   if (env.refstr)
-    argcv_free (-1, env.refstr);
+    argv_free (env.refstr);
 }	
 
 void
